//	This work is licensed under the Creative Commons Attribution-ShareAlike 3.0 Unported License.
//	To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/ or send a
//	letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.

//	Persistence of Vision Ray Tracer version 3.8 Include File
//	File: KeywordExamples.inc
//	Last updated: 2021.3.7
/*	Description: Companion file for: Code examples for all of the keywords in SDL
			pigments
			color_maps
			textures
			functions
			macros
			scene setup for rendering: such as camera and other extensive code
*/

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100

// Vectors
#declare xy = x + y;
#declare xz = x + z;
#declare yz = y + z;
			
// Bald Eagle
#declare E = 0.000001;
#declare V_Unit = <1, 1, 1>;
#declare V_Half = 0.5 * V_Unit;
#declare P_White = pigment {rgb <1, 1, 1>}
#declare P_Gray = pigment {rgb <1, 1, 1>*0.5}
#declare T_Red = texture {pigment {rgb <0.50, 0.00, 0.00>}}
#declare T_Grn = texture {pigment {rgb <0.00, 0.50, 0.00>}}
#declare T_Blu = texture {pigment {rgb <0.00, 0.00, 0.50>}}
#declare T_Yel = texture {pigment {rgb <0.55, 0.55, 0.00>}}
#declare T_Blk = texture {pigment {rgb <0.00, 0.00, 0.00>}}	
#declare T_Wht = texture {pigment {rgb <1.00, 1.00, 1.00>}}	
#declare T_Tan = texture {pigment {rgb <0.92, 0.60, 0.20>} finish {diffuse 0.7 specular 0.2 reflection 0.02}}
#declare Checker = texture {pigment {checker rgb 0 rgb 1} scale 2 finish {diffuse 1}}
	
#declare Square = union {
	triangle {<-5, 0, -5>, <-5, 0, 5>, <5, 0, -5>}
	triangle {<5, 0, -5>, <-5, 0, 5>, <5, 0, 5> }
	texture {Checker}
}

#declare Axes =
	union {
		#declare Line = 0.1;
		#declare Base = Line*3;
		#declare Length = 3.5;
		#declare Ext = 0.5;
		cylinder {<0, 0, 0>, <Length, 0, 0>, Line texture {_Red}}
			cone {<Length, 0, 0>, Base, <Length+Ext, 0, 0>, 0 texture {_Red}}
			text {ttf "timrom.ttf", "X", 0.02, 0.0 texture {_Red}
				translate <2, -1.125, 0>
			}

		cylinder {<0, 0, 0>, <0, Length, 0>, Line texture {_Green}}
			cone {<0, Length, 0>, Base, <0, Length+Ext, 0>, 0 texture {_Green}}
		cylinder {<0, 0, 0>, <0, 0, Length>, Line texture {_Blue}}
			cone {<0, 0, Length>, Base, <0, 0, Length+Ext>, 0 texture {_Blue}}
		//no_shadow
	}

// end Bald Eagle

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100
#macro BasicScene (Center, SkySphereColor)	
	camera {
		location  Center-z*20
		right     x*image_width/image_height
		up 		y
		look_at   Center
	}
	sky_sphere {pigment {SkySphereColor}}
	light_source {Center-z*20 color rgb 1}
#end // end macro BasicScene

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100

#macro OrthoScene (Center, SkySphereColor, Zoom)
	//#local Zoom = 1;   // this many pixels will cover 1 pov unit	
	camera {
		orthographic
		location  Center-(z*20)
		right     x*image_width/Zoom
		up 		y*image_height/Zoom
		look_at   Center
	}
	sky_sphere {pigment {SkySphereColor}}
	light_source {Center-z*20+(-x+y)*5 color rgb 1}
#end // end macro OrthoScene

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100

#macro GraphCircularEquation (Amin, Amax, Step, Line)
	// Bald Eagle 2021
	sphere {0 Line texture {T_Wht}}
	torus {1 Line texture {T_Wht} }
	union {
		#for (AA, Amin, Amax, Step)
			#local Current = <cos (AA), sin (AA), 0>;
			sphere {_Vector Line*3 texture {T_Grn}}
		#end // end for XX
		//texture {T_Blu}
		no_shadow
	} // end union
#end // end macro GraphCircularEquation

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100

#macro GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	// Bald Eagle 2021
	sphere {0 Line texture {T_Wht}}
	cylinder {x*Xmin, x*Xmax Line texture {T_Red} }
	cylinder {y*Ymin, y*Ymax Line texture {T_Grn} }
	#local NotFirstPoint = false;
	union {
		#for (XX, Xmin, Xmax, Step)
			#local Current = <XX, Function (XX), 0>;
			sphere {Current Line}
			#if (NotFirstPoint)
				cylinder {Last, Current Line}
			#end // end if
			#declare Last = Current;
			#local NotFirstPoint = true;
		#end // end for XX
		texture {T_Blu}
		no_shadow
	} // end union
#end // end macro GraphLinearEquation

