#version 3.8;
global_settings {assumed_gamma 1.0} 


// Use this to select which code example to run.
#declare Keyword = "isosurface";




//	This work is licensed under the Creative Commons Attribution-ShareAlike 3.0 Unported License.
//	To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/ or send a
//	letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.

//	Persistence of Vision Ray Tracer version 3.8 Include File
//	File: KeywordExamples.pov
//	Last updated: 2021.3.27
//	Description: Code examples for all of the keywords in SDL
	
//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100

/*
	Development notes:
	
	Until all of the keywords have at least a basic functional example,
	I propose each edited version use a filename KeywordExamples_Dev_M_m_p_Author.pov
	This consistent with clipka's admonition that Semantic Versioning be used to track changes.
	https://semver.org/
	Given a version number MAJOR.MINOR.PATCH, increment the:
	MAJOR version when you make incompatible API changes,
	MINOR version when you add functionality in a backwards compatible manner, and
	PATCH version when you make backwards compatible bug fixes.
	
	Then the latest file can be named:
	KeywordExamples_M_m_p.pov
	
	Try to use the /deprecated/ keyword in examples of older syntaxes, etc.
	disambiguate keywords with multiple usage (see examples below)
	Make examples as fun as possible, and provide examples of clever and unusual usage
	As much as possible, try to create at least one example consistent with documentation style

	A companion file, to hold anything which might unnecessarily clutter this file
	will be invoked using #include "KeywordExamples.inc"
		(Not sure if KeywordExamples.inc should just have one line: #include "KeywordExamples_M_m_p.inc"
		or we should just use a matching #include "KeywordExamples_M_m_p.inc" in this file)
		Use the include file for:
			pigments
			color_maps
			textures
			functions
			macros
			scene setup for rendering: such as camera and other extensive code
	
	I suggest that helpful suggestions and comments for further editing be appended to a file called
	KeywordExamples.txt
	
	And all files in this project be put into a KeywordExamples_M_m_p.zip
*/

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100



#if (file_exists ("KeywordExamples.inc"))
	#include "KeywordExamples.inc"
#end

// Keywords Reference
// http://wiki.povray.org/content/Reference:Keywords
// POV-Ray has a number of reserved keywords which are listed below.


// #####################################################################################################
#declare Ambiguous = "Ambiguous keyword: more than one usage instance occurs in SDL! \n";
#declare NE = "Stopping render of objectless scene.  No code example for this keyword yet. \n"
#declare NO = "Stopping render of objectless scene.  Check #debug stream in console output. \n"
// #####################################################################################################



// ################################################# A #################################################

#declare this_keyword = "aa_level";
#if (Keyword = this_keyword)  
	// Code example for keyword: aa_level 
	// You can specify the anti-aliasing recursion depth using the aa_level keyword followed by an integer.
	// The default for aa_level is 4
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	aa_level 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "aa_threshold";
#if (Keyword = this_keyword)  
	// Code example for keyword: aa_threshold 
	// You can specify the anti-aliasing threshold by using the aa_threshold followed by a float.
	// The default for aa_level is 4 and the default aa_threshold is 0.1.
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	aa_threshold 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "abs";
#if (Keyword = this_keyword)  
	// Code example for keyword: abs 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/*
	Absolute value of N. If N is negative, returns -N otherwise returns N.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#for (N, -1, 1, 0.1)
		#local N = min(max(N, -1), 1);	// clamp N = -/+1
		#local _result = abs (N);
		#debug concat ("abs (", str (N, 5, 2), ") = ", str (_result, 0, 4), " \n")
	#end
	#error NO	// Stop render
	/*
	#local abs = function (N) {select (N, -N, 0, N)}
	#local abs = function (N) {((N<0) ? (-N) : (N))}
	*/
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "absorption";
#if (Keyword = this_keyword)  
	// Code example for keyword: absorption 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	*/
	
	 
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "accuracy";
#if (Keyword = this_keyword)  
	// Code example for keyword: accuracy 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	The isosurface finding method is a recursive subdivision method. 
	This subdivision goes on until the length of the interval where POV-Ray finds 
	a surface point is less than the specified accuracy. The default value is 0.001.
	Smaller values produces more accurate surfaces, but it takes longer to render.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	Also see: isosurface
	*/ 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "acos";
#if (Keyword = this_keyword)  
	// Code example for keyword: acos 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	Returns the angle, expressed in radians, whose cosine is N.
	For real input to acos (N), N should be in the range -1 to +1.
	For real input, the output range of ACOS is between 0 and π.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Acos = function (_N) {acos (_N)}
	#for (N, -1, 1, 0.1)
		#local N = min(max(N, -1), 1);	// clamp N = -/+1
		#debug concat ("acos (", str (N, 5, 2), ") = ", str (Acos(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (y*pi/2, P_White, 130)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Acos, -1, 1, 0, pi, pi/90, 0.01)

	/*
	Coding syntax notes:
	Passing values outside of -1 to +1 to acos will result in an error:
	Parse Warning: Domain error in acos.
	So you may want to sanity check / limit your input as follows:
	#local N = min(max(N, -1), 1);
	#local N = max(min(N, 1), -1);
	#local N = (N < -1) ? -1 : ((N > 1) ? 1 : N)
	*/
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "acosh";
#if (Keyword = this_keyword)  
	// Code example for keyword: acosh 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	https://franz.com/support/documentation/ansicl.94/dictentr/sinhcosh.htm
	The following definition for the inverse hyperbolic cosine determines the range and branch cuts:
	arccosh z = 2 log (sqrt((z+1) /2) + sqrt((z-1)/2)).
	The branch cut for the inverse hyperbolic cosine function lies along the real axis 
	to the left of 1 (inclusive), extending indefinitely along the negative real axis, 
	continuous with quadrant II and (between 0 and 1) with quadrant I. 
	The range is that half-strip of the complex plane containing numbers whose real part 
	is non-negative and whose imaginary part is between - pi (exclusive) and  pi (inclusive). 
	A number with real part zero is in the range if its imaginary part is between zero (inclusive) 
	and  pi (inclusive).
	The result of acosh may be a complex even if number is not a complex; this occurs when number is 
	less than one. Also, the result of atanh may be a complex even if number is not a complex; 
	this occurs when the absolute value of number is greater than one.
	https://www.mathworks.com/help/matlab/ref/acosh.html
	acosh(x)=log(x+sqrt(pow(x,2)−1))

	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Acosh = function (_N) {acosh (_N)}
	#for (N, 0, tau, 0.1)
		#debug concat ("acosh (", str (N, 5, 2), ") = ", str (Acosh(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<3, 1.25, 0>, P_White, 100)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Acosh, 0, tau, 0, 2.5, tau/90, 0.01)
	/* 
	*/

#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adaptive";
#if (Keyword = this_keyword)  
	// Code example for keyword: adaptive 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	The adaptive keyword is used to enable adaptive sampling of the light source. By default POV-Ray 
	calculates the amount of light that reaches a surface from an area light by shooting a test ray 
	at every point light within the array. As you can imagine this is very slow. Adaptive sampling on 
	the other hand attempts to approximate the same calculation by using a minimum number of test rays. 
	The number specified after the keyword controls how much adaptive sampling is used. The higher the 
	number the more accurate your shadows will be but the longer they will take to render. If you are 
	not sure what value to use a good starting point is adaptive 1. The adaptive keyword only accepts 
	integer values and cannot be set lower than 0.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	
	*/

	adaptive 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adc_bailout";
#if (Keyword = this_keyword) 
	// KEYWORD DISAMBIGUATION BLOCK
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "adc_bailout global setting \n"
	#warning " - or - \n"
	#warning "adc_bailout radiosity \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adc_bailout global setting";
#if (Keyword = this_keyword) 
	// Code example for keyword: adc_bailout global setting
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	*/ 
	// Code example for keyword: adc_bailout global setting 
	adc_bailout global setting 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "adc_bailout radiosity";
#if (Keyword = this_keyword)  
	// Code example for keyword: adc_bailout 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	*/
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "agate";
#if (Keyword = this_keyword)  
	// Code example for keyword: agate 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render

#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "agate_turb";
#if (Keyword = this_keyword)  
	// Code example for keyword: agate_turb 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 

#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "albedo";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "albedo diffuse \n"
	#warning " - or - \n"
	#warning "albedo phong \n"
	#warning " - or - \n"
	#warning "albedo specular \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "albedo diffuse";
#if (Keyword = this_keyword)  
	// Code example for keyword: albedo diffuse
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "albedo phong";
#if (Keyword = this_keyword)  
	// Code example for keyword: albedo phong
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "albedo specular";
#if (Keyword = this_keyword)  
	// Code example for keyword: albedo specular
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: albedo specular 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "all";
#if (Keyword = this_keyword)  
	// Code example for keyword: all
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: all 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end 
 
// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "all_intersections";
#if (Keyword = this_keyword)  
	// Code example for keyword: all_intersections 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	// To check for all surfaces, use the keyword all_intersections instead.
	// With all_intersections POV-Ray keeps looking until all surfaces are found.
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "alpha";
#if (Keyword = this_keyword)  
	// Code example for keyword: alpha 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render

#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "altitude";
#if (Keyword = this_keyword)  
	// Code example for keyword: altitude
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: altitude 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "always_sample";
#if (Keyword = this_keyword)  
	// Code example for keyword: always_sample 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: always_sample 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ambient";
#if (Keyword = this_keyword)  
	// Code example for keyword: ambient
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ambient 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ambient_light";
#if (Keyword = this_keyword)  
	// Code example for keyword: ambient_light
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ambient_light 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 
 
// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "angle";
#if (Keyword = this_keyword)  
	// Code example for keyword: angle
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: angle 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "aoi";
#if (Keyword = this_keyword)  
	// Code example for keyword: aoi 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: aoi 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "aperture";
#if (Keyword = this_keyword)  
	// Code example for keyword: aperture
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: aperture 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "append";
#if (Keyword = this_keyword)  
	// Code example for keyword: append
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: append 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "arc_angle";
#if (Keyword = this_keyword)  
	// Code example for keyword: arc_angle
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: arc_angle 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "area_illumination";
#if (Keyword = this_keyword)  
	// Code example for keyword: area_illumination 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: area_illumination 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "area_light";
#if (Keyword = this_keyword)  
	// Code example for keyword: area_light
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: area_light 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "array";
#if (Keyword = this_keyword)  
	// Code example for keyword: array
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: array 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  
*/
// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "asc";
#if (Keyword = this_keyword)  
	// Code example for keyword: asc 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#for (N, 32, 126)
		#local Glyph = chr(N);			// generate a 1-character long string from the loop variable
		#local AsciiVal = asc (Glyph);	// Determine the ASCII value of the character
		#debug concat ("The ASCII value for ", chr(34), Glyph, chr(34), " is ", str (AsciiVal, 0, 0), " \n")
	#end
	#error NO	// Stop render
	/*
	Also see: chr (N)
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ascii";
#if (Keyword = this_keyword)  
	// Code example for keyword: ascii  
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	*/

ascii 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "asin";
#if (Keyword = this_keyword)  
	// Code example for keyword: asin 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	For real values of X in the interval [-1, 1], asin(X) returns values in the interval [-π/2, π/2].
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Asin = function (_N) {asin (_N)}
	#for (N, -1, 1, 0.1)
		#debug concat ("asin (", str (N, 5, 2), ") = ", str (Asin(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 130)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Asin, -1, 1, -pi/2, pi/2, pi/360, 0.01)
	/* 
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "asinh";
#if (Keyword = this_keyword)  
	// Code example for keyword: asinh
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	https://franz.com/support/documentation/ansicl.94/dictentr/sinhcosh.htm
	The following definition for the inverse hyperbolic sine determines the range and branch cuts:
	arcsinh z = log (z+sqrt(1+z2)).
	The branch cut for the inverse hyperbolic sine function is in two pieces: one along the positive 
	imaginary axis above i (inclusive), continuous with quadrant I, and one along the negative 
	imaginary axis below -i (inclusive), continuous with quadrant III. The range is that strip of 
	the complex plane containing numbers whose imaginary part is between - pi /2 and  pi /2. 
	A number with imaginary part equal to - pi /2 is in the range if and only if its real part 
	is non-positive; a number with imaginary part equal to pi /2 is in the range if and only if its 
	imaginary part is non-negative.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Asinh = function (_N) {asinh (_N)}
	#for (N, -tau, tau, tau/10)
		#debug concat ("asinh (", str (N, 5, 2), ") = ", str (Asinh(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 100)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Asinh, -tau, tau, -2.5, 2.5, tau/360, 0.01)
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "assumed_gamma";
#if (Keyword = this_keyword)  
	// Code example for keyword: assumed_gamma 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "atan";
#if (Keyword = this_keyword)  
	// Code example for keyword: atan 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Atan = function (_N) {atan (_N)}
	#for (N, -20, 20, 5)
		#debug concat ("atan (", str (N, 5, 2), ") = ", str (Atan(N), 0, 4), " radians \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 100)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Atan, -20, 20, -1.5, 1.5, tau/360, 0.01)
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------
 
#declare this_keyword = "atan2";
#if (Keyword = this_keyword) 
	// Code example for keyword: atan2
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	atan2 (y, x) returns the four-quadrant inverse tangent (tan-1) of Y and X
	The four-quadrant inverse tangent, atan2(Y,X), returns values in the closed interval [-pi,pi] 
	based on the values of Y and X.
	(In contrast, atan(Y/X) returns results that are limited to the interval [-pi/2,pi/2])
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Line = 0.01;
	sphere {0 Line*2 texture {T_Wht}}
	torus {1 Line texture {T_Blu} rotate x*90}
	#macro PlotAtan2 (X, Y, Line)
		#local _Vector = <X, Y, 0>;
		sphere {_Vector Line*3 texture {T_Grn}}
		cylinder {0, _Vector Line texture {T_Blk} no_shadow}
		#local _Angle = atan2 (Y, X);
		#local _Angled = _Angle * 180/pi;
		cylinder {0, x*0.9 Line*1.5 rotate z*_Angled texture {T_Red} no_shadow}
		cone {x*0.9, Line*4.5, x, 0 rotate z*_Angled texture {T_Red} no_shadow}
	#end // end macro PlotAtan2 
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_Gray, 100)
	#for (Y, -2, 2, 4)
		#for (X, -2, 2, 0.5)
			PlotAtan2 (X, Y, Line)
		#end // end for X
	#end // end for Y
	#for (X, -2, 2, 4)
		#for (Y, -2, 2, 0.5)
			PlotAtan2 (X, Y, Line)
		#end // end for X
	#end // end for Y
	/* 
	atan2 is an extremely useful function when you need to calculate the angle of a 
	point or vector.
	*/ 
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "atand";
#if (Keyword = this_keyword)  
	// Code example for keyword: atand 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	atand
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Atand = function (_N) {atand (_N)}
	#for (N, -20, 20, 5)
		#debug concat ("atand (", str (N, 5, 2), ") = ", str (Atand(N), 0, 4), " degrees \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 100)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Atand, -20, 20, -1.5, 1.5, tau/360, 0.01)
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "atanh";
#if (Keyword = this_keyword)  
	// Code example for keyword: atanh
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	https://franz.com/support/documentation/ansicl.94/dictentr/sinhcosh.htm
	The following definition for the inverse hyperbolic tangent determines the range and branch cuts:
	arctanh z = (log (1+z) - log (1-z))/2.
	Note that:
	i arctan z = arctanh iz.
	The branch cut for the inverse hyperbolic tangent function is in two pieces: one along the 
	negative real axis to the left of -1 (inclusive), continuous with quadrant III, and one along the 
	positive real axis to the right of 1 (inclusive), continuous with quadrant I. The points -1 and 1 are 
	excluded from the domain. The range is that strip of the complex plane containing numbers whose 
	imaginary part is between - pi /2 and pi /2. A number with imaginary part equal to - pi /2 is in 
	the range if and only if its real part is strictly negative; a number with imaginary part equal to 
	pi /2 is in the range if and only if its imaginary part is strictly positive. Thus the range of the 
	inverse hyperbolic tangent function is identical to that of the inverse hyperbolic sine function 
	with the points - pi i/2 and  pi i/2 excluded.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Atanh = function (_N) {atanh (_N)}
	#for (N, -1, 1, 0.01)
		#debug concat ("atanh (", str (N, 5, 2), ") = ", str (Atanh(N), 0, 4), " degrees \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 100)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Atanh, -1, 1, -3, 3, tau/360, 0.01)
	/* 
	*/
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "autostop";
#if (Keyword = this_keyword)  
	// Code example for keyword: autostop  
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "average";
#if (Keyword = this_keyword) 
	// Code example for keyword: average
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/* 
	*/ 
#end  

// ################################################# B #################################################

#declare this_keyword = "b_spline";
#if (Keyword = this_keyword)  
	// Code example for keyword: b_spline
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "background";
#if (Keyword = this_keyword)  
	// Code example for keyword: background 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bezier_spline";
#if (Keyword = this_keyword)  
	// Code example for keyword: bezier_spline
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bicubic_patch";
#if (Keyword = this_keyword)  
	// Code example for keyword: bicubic_patch
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bitwise_and";
#if (Keyword = this_keyword)  
	// Code example for keyword: bitwise_and
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bitwise_or";
#if (Keyword = this_keyword)  
	// Code example for keyword: bitwise_or
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bitwise_or
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bitwise_xor";
#if (Keyword = this_keyword)  
	// Code example for keyword: bitwise_xor 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bitwise_xor
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "black_hole";
#if (Keyword = this_keyword)  
	// Code example for keyword: black_hole
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: black_hole
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "blend_gamma color map";
#if (Keyword = this_keyword)  
	// Code example for keyword: blend_gamma color map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: blend_gamma color map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "blend_gamma pigment map";
#if (Keyword = this_keyword)  
	// Code example for keyword: blend_gamma pigment map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: blend_gamma pigment map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "blend_mode color map";
#if (Keyword = this_keyword)  
	// Code example for keyword: blend_mode color map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: blend_mode color map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "blend_mode pigment map";
#if (Keyword = this_keyword)  
	// Code example for keyword: blend_mode pigment map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: blend_mode pigment map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "blob";
#if (Keyword = this_keyword)  
	// Code example for keyword: blob
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: blob
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "blue";
#if (Keyword = this_keyword)  
	// Code example for keyword: blue
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: blue
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "blur_samples";
#if (Keyword = this_keyword)  
	// Code example for keyword: blur_samples
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: blur_samples
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bokeh";
#if (Keyword = this_keyword)  
	// Code example for keyword: bokeh
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bokeh
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bounded_by";
#if (Keyword = this_keyword)  
	// Code example for keyword: bounded_by
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bounded_by
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "box";
#if (Keyword = this_keyword)  
	// Code example for keyword: box
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: box
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "boxed";
#if (Keyword = this_keyword)  
	// Code example for keyword: boxed
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: boxed
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bozo";
#if (Keyword = this_keyword)  
	// Code example for keyword: bozo
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bozo
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "break";
#if (Keyword = this_keyword)  
	// Code example for keyword: break
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: break
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "brick";
#if (Keyword = this_keyword)  
	// Code example for keyword: brick
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: brick
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "brick_size";
#if (Keyword = this_keyword)  
	// Code example for keyword: brick_size
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: brick_size
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "brightness";
#if (Keyword = this_keyword)  
	// Code example for keyword: brightness
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: brightness
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "brilliance";
#if (Keyword = this_keyword)  
	// Code example for keyword: brilliance 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: brilliance
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bump_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: bump_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bump_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bump_size";
#if (Keyword = this_keyword)  
	// Code example for keyword: bump_size
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bump_size
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bumps";
#if (Keyword = this_keyword)  
	// Code example for keyword: bumps
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bumps
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt709 bump map";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt709 bump map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt709 bump map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt709 height field";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt709 height field
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt709 height field
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt709 image map";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt709 image map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt709 image map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt709 image pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt709 image pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt709 image pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt2020 bump map";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt2020 bump map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt2020 bump map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt2020 height field";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt2020 height field
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt2020 height field
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt2020 image map";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt2020 image map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt2020 image map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "bt2020 image pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: bt2020 image pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: bt2020 image pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// ################################################# C #################################################

#declare this_keyword = "camera";
#if (Keyword = this_keyword)  
	// Code example for keyword: camera 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: camera
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "case";
#if (Keyword = this_keyword) 
	// Code example for keyword: case
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: case
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "caustics";
#if (Keyword = this_keyword)  
	// Code example for keyword: caustics
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: caustics
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ceil";
#if (Keyword = this_keyword)  
	// Code example for keyword: ceil
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ceil
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cells";
#if (Keyword = this_keyword)  
	// Code example for keyword: cells
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cells
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "charset";
#if (Keyword = this_keyword)  
	// Code example for keyword: charset
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: charset
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "checker";
#if (Keyword = this_keyword)  
	// Code example for keyword: checker
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: checker
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "chr";
#if (Keyword = this_keyword)  
	// Code example for keyword: chr 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#for (N, 32, 126)
		#local Glyph = chr(N);			// generate a 1-character long string from the loop variable
		#debug concat ("ASCII value ", str (N, 0, 0), " codes for: ", chr(34), Glyph, chr(34), " \n")
	#end
	#error NO	// Stop render
	/*
	Also see: asc (N)
	*/
#end 

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "circular";
#if (Keyword = this_keyword)  
	// Code example for keyword: circular
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: circular
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "clipped_by";
#if (Keyword = this_keyword)  
	// Code example for keyword: clipped_by
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: clipped_by
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "clock";
#if (Keyword = this_keyword)  
	// Code example for keyword: clock
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: clock
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "clock_delta";
#if (Keyword = this_keyword)  
	// Code example for keyword: clock_delta
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: clock_delta
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "clock_on";
#if (Keyword = this_keyword)  
	// Code example for keyword: clock_on
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: clock_on
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "collect";
#if (Keyword = this_keyword)  
	// Code example for keyword: collect
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: collect
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "color";
#if (Keyword = this_keyword)  
	// Code example for keyword: color
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: color
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "color_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: color_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: color_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "colour";
#if (Keyword = this_keyword)  
	// Code example for keyword: colour
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: colour
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "colour_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: colour_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: colour_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end

// -----------------------------------------------------------------------------------------------------
  
#declare this_keyword = "component";
#if (Keyword = this_keyword) 
	// Code example for keyword: component
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by: 
	// Code example for keyword: component
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	//The component keyword is an obsolete method for specifying a spherical 
	//component and is only used for compatibility with earlier POV-Ray versions. 
	//It may not have textures or transformations individually applied to it.
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "composite";
#if (Keyword = this_keyword)  
	// Code example for keyword: composite
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: composite
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	//Earlier versions of POV-Ray placed restrictions on unions so you often had to combine objects with 
	//composite statements. Those earlier restrictions have been lifted so composite is no longer needed. 
	//It is still supported for backwards compatibility.
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "concat";
#if (Keyword = this_keyword)  
	// Code example for keyword: concat
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: concat
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cone";
#if (Keyword = this_keyword)  
	// Code example for keyword: cone 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cone
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "confidence";
#if (Keyword = this_keyword)  
	// Code example for keyword: confidence
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: confidence
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "conic_sweep";
#if (Keyword = this_keyword)  
	// Code example for keyword: conic_sweep 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: conic_sweep
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "conserve_energy";
#if (Keyword = this_keyword)  
	// Code example for keyword: conserve_energy
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: conserve_energy
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "contained_by";
#if (Keyword = this_keyword) 
	// Code example for keyword: contained_by
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by: 
	// Code example for keyword: contained_by
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	//The contained_by 'object' limits the area where POV-Ray samples for the surface of the function. 
	//This container can either be a sphere or a box, both of which use the standard POV-Ray syntax. 
	//If not specified a box {<-1,-1,-1>, <1,1,1>} will be used as default.
	//contained_by {sphere {CENTER, RADIUS}}
	//contained_by {box {CORNER1, CORNER2}}
#end  


#declare this_keyword = "control0";
#if (Keyword = this_keyword)  
	// Code example for keyword: control0
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: control0
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "control1";
#if (Keyword = this_keyword)  
	// Code example for keyword: control1 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: control1
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "coords";
#if (Keyword = this_keyword)  
	// Code example for keyword: coords
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: coords
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

*/

// -----------------------------------------------------------------------------------------------------
#declare this_keyword = "cos";
#if (Keyword = this_keyword)  
	// Code example for keyword: cos 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#local Cos = function (_N) {cos (_N)}
	#for (N, 0, tau, tau/90)
		#debug concat ("cos (", str (N, 5, 2), ") = ", str (Cos(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 130)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Acos, 0, tau, -1, 1, tau/90, 0.01)
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cosh";
#if (Keyword = this_keyword)  
	// Code example for keyword: cosh 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	// https://en.wikipedia.org/wiki/Catenary#Equation
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Cosh = function (_N) {cosh (_N)}
	#for (N, -5, 5, 1)
		#debug concat ("cosh (", str (N, 5, 2), ") = ", str (Cosh(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 100)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Atand, -5, 5, 0, 80, tau/360, 0.01)
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "count";
#if (Keyword = this_keyword)  
	// Code example for keyword: count 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: count
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "crackle";
#if (Keyword = this_keyword)  
	// Code example for keyword: crackle
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: crackle
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "crand";
#if (Keyword = this_keyword)  
	// Code example for keyword: crand 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: crand
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	
	finish {
		#if (clock_on)
			// NO CRAND!
		#else
			crand 0.05
		#end
	}
	#error NE // Stop render
	/*
	Very rough surfaces, such as concrete or sand, exhibit a dark graininess in their apparent color. 
	This is caused by the shadows of the pits or holes in the surface. The crand keyword can be added 
	to a finish to cause a minor random darkening in the diffuse reflection of direct illumination. 
	Typical values range from crand 0.01 to crand 0.5 or higher. The default value is 0. For example:
	finish { crand 0.05 }
	The grain or noise introduced by this feature is applied on a pixel-by-pixel basis. This means that 
	it will look the same on far away objects as on close objects. The effect also looks different depending 
	upon the resolution you are using for the rendering.
	Note: The crand should not be used when rendering animations. This is the one of a few truly random 
	features in POV-Ray and will produce an annoying flicker of flying pixels on any textures animated 
	with a crand value. For these reasons it is not a very accurate way to model the rough surface effect.
	*/
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cube";
#if (Keyword = this_keyword)  
	// Code example for keyword: cube
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cube
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cubic";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "cubic object \n"
	#warning " - or - \n"
	#warning "cubic pattern \n"
	#warning " - or - \n"
	#warning "cubic warp \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cubic object";
#if (Keyword = this_keyword)  
	// Code example for keyword: cubic object
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cubic object
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cubic pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: cubic pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cubic pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cubic warp";
#if (Keyword = this_keyword)  
	// Code example for keyword: cubic warp
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cubic warp
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cubic_spline";
#if (Keyword = this_keyword)  
	// Code example for keyword: cubic_spline
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cubic_spline
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cubic_wave";
#if (Keyword = this_keyword)  
	// Code example for keyword: cubic_wave
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cubic_wave
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cutaway_textures";
#if (Keyword = this_keyword)  
	// Code example for keyword: cutaway_textures
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cutaway_textures
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cylinder";
#if (Keyword = this_keyword)  
	// Code example for keyword: cylinder
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cylinder
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "cylindrical";
#if (Keyword = this_keyword)  
	// Code example for keyword: cylindrical
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: cylindrical
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# D #################################################

#declare this_keyword = "datetime";
#if (Keyword = this_keyword)  
	// Code example for keyword: datetime 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: datetime
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "debug";
#if (Keyword = this_keyword)  
	// Code example for keyword: debug 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: debug
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "declare";
#if (Keyword = this_keyword)  
	// Code example for keyword: declare
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: declare
	
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "default";
#if (Keyword = this_keyword)  
	// Code example for keyword: default 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: default
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "defined";
#if (Keyword = this_keyword)  
	// Code example for keyword: defined
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: defined
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "degrees";
#if (Keyword = this_keyword)  
	// Code example for keyword: degrees 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Degrees = function (_N) {degrees (_N)}
	#for (N, -0, tau, 5)
		#debug concat ("degrees (", str (N, 5, 2), ") = ", str (Degrees(N), 0, 4), " degrees \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 100)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Degrees, 0, tau, 0, 360, tau/360, 0.01) 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "density";
#if (Keyword = this_keyword)  
	// Code example for keyword: density
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: density
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "density_file";
#if (Keyword = this_keyword)  
	// Code example for keyword: density_file
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: density_file
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "density_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: density_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: density_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "dents";
#if (Keyword = this_keyword)  
	// Code example for keyword: dents
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: dents
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "deprecated";
#if (Keyword = this_keyword)  
	// Code example for keyword: deprecated 
	/*
	deprecated 
	The ability to add a deprecated flag to a #declare has been added. 
	This is to aid in migrating scenes away from old constructs (e.g. old textures). 
	The usage is illustrated below:
	#declare deprecated Col_Glass_Old=color rgbf <0.8, 0.9, 0.85, 0.85>;
	#declare deprecated once Col_Glass_Old=... etc
	#declare deprecated "Some message" Col_Glass_Old=... etc
	A deprecated identifier generates no message at the time it is declared, a warning is only issued if it is used.
	If the optional once keyword is present it must immediately follow the deprecated keyword 
	and indicates that the warning should only be displayed once per parse.
	If the optional message string is present, it will be used as the warning to be displayed if the identifier is used. 
	Otherwise, a message in the form "Identifier Col_Glass_Old was declared deprecated." is used.
	An identifier is considered used if it is referenced anywhere (even if in another #declare).
	*/
#end  


#declare this_keyword = "df3";
#if (Keyword = this_keyword)  
	// Code example for keyword: df3
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: df3
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  
// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "dictionary";
#if (Keyword = this_keyword)  
	// Code example for keyword: dictionary 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: dictionary
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  
// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "difference csg";
#if (Keyword = this_keyword)  
	// Code example for keyword: difference csg
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: difference csg
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "difference torus";
#if (Keyword = this_keyword)  
	// Code example for keyword: difference torus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: difference torus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "diffuse";
#if (Keyword = this_keyword)  
	// Code example for keyword: diffuse
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: diffuse
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "dimension_size";
#if (Keyword = this_keyword)  
	// Code example for keyword: dimension_size
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: dimension_size
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "dimensions";
#if (Keyword = this_keyword)  
	// Code example for keyword: dimensions
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: dimensions
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "direction";
#if (Keyword = this_keyword)  
	// Code example for keyword: direction
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: direction
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "disc";
#if (Keyword = this_keyword)  
	// Code example for keyword: disc
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: disc
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "dispersion";
#if (Keyword = this_keyword)  
	// Code example for keyword: dispersion
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: dispersion
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "dispersion_samples";
#if (Keyword = this_keyword)  
	// Code example for keyword: dispersion_samples
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: dispersion_samples
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "dist_exp";
#if (Keyword = this_keyword)  
	// Code example for keyword: dist_exp 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: dist_exp
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "distance fog";
#if (Keyword = this_keyword)  
	// Code example for keyword: distance fog
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: distance fog
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "distance ovus";
#if (Keyword = this_keyword)  
	// Code example for keyword: distance ovus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: distance ovus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "div";
#if (Keyword = this_keyword)  
	// Code example for keyword: div
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")

	#for (N, 1, 11, 2)
		#debug concat (str (N+2, 0, 0), " / ", str (N, 0, 0), " = ", str ((N+2)/N, 0, 4), " \n")
		#debug concat ("div (", str (N+2, 0, 0), " / ", str (N, 0, 0), ") = ", str (div(N), 0, 4), " \n")
		
	#end
	#error NO	// Stop render
 
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "double_illuminate";
#if (Keyword = this_keyword)  
	// Code example for keyword: double_illuminate
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: double_illuminate
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# E #################################################

#declare this_keyword = "eccentricity";
#if (Keyword = this_keyword)  
	// Code example for keyword: eccentricity
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: eccentricity
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "else";
#if (Keyword = this_keyword)  
	// Code example for keyword: else
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: else
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "elseif";
#if (Keyword = this_keyword)  
	// Code example for keyword: elseif 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: elseif
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------
*/
#declare this_keyword = "emission";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "emission finish \n"
	#warning " - or - \n"
	#warning "emission media \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "emission finish";
#if (Keyword = this_keyword)  
	// Code example for keyword: emission finish
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: emission finish
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "emission media";
#if (Keyword = this_keyword)  
	// Code example for keyword: emission media
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: emission media 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "end";
#if (Keyword = this_keyword)  
	// Code example for keyword: end 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: end 
	// for if ifdef ifndef macro while switch
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "error";
#if (Keyword = this_keyword)  
	// Code example for keyword: error
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: error
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "error_bound";
#if (Keyword = this_keyword)  
	// Code example for keyword: error_bound
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: error_bound
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "evaluate";
#if (Keyword = this_keyword)  
	// Code example for keyword: evaluate
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: evaluate 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/*
	POV-Ray can also dynamically adapt the used max_gradient. 
	To activate this technique you have to specify the evaluate keyword followed by three parameters:
	P0: the minimum max_gradient in the estimation process,
	P1: an over-estimating factor. This means that the max_gradient is multiplied by the P1 parameter.
	P2: an attenuation parameter (1 or less)
	In this case POV-Ray starts with the max_gradient value P0 and dynamically changes it during the render 
	using P1 and P2. In the evaluation process, the P1 and P2 parameters are used in quadratic functions. 
	This means that over-estimation increases more rapidly with higher values and attenuation more rapidly 
	with lower values. Also with dynamic max_gradient, there can be artefacts and holes.
	If you are unsure what values to use, start a render without evaluate to get a value for max_gradient. 
	Now you can use it with evaluate like this:
	P0 : found max_gradient * min_factor
	'min_factor' being a float between 0 and 1 to reduce the max_gradient to a 'minimum max_gradient'. 
	The ideal value for P0 would be the average of the found max_gradients, but we do not have access to that information.
	A good starting point is 0.6 for the min_factor
	P1 : sqrt(found max_gradient/(found max_gradient * min_factor))
	'min_factor' being the same as used in P0 this will give an over-estimation factor of more than 1, 
	based on your minimum max_gradient and the found max_gradient.
	P2 : 1 or less
	0.7 is a good starting point.
	*/
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "exp";
#if (Keyword = this_keyword)  
	// Code example for keyword: exp exp #end  
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	// exp (A) Exponential of A. 
	// Returns the value of e raised to the power A where e is the base of the natural logarithm, 
	// i.e. the non-repeating value approximately equal to 2.71828182846.
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Exp = function (_N) {exp (_N)}
	#for (N, 0, 5, 1)
		#debug concat ("exp (", str (N, 0, 0), ") = ", str (Exp(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<2.5, 10, 0>, P_White, 20)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Exp, 0, 3, 0, 20, 0.1, 0.06) 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "expand_thresholds";
#if (Keyword = this_keyword)  
	// Code example for keyword: expand_thresholds
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: expand_thresholds
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "exponent";
#if (Keyword = this_keyword)  
	// Code example for keyword: exponent
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: exponent
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "exterior";
#if (Keyword = this_keyword)  
	// Code example for keyword: exterior
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: exterior
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "extinction";
#if (Keyword = this_keyword)  
	// Code example for keyword: extinction
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: extinction
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# F #################################################

#declare this_keyword = "face_indices ";
#if (Keyword = this_keyword)  
	// Code example for keyword: face_indices 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: face_indices 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "facets";
#if (Keyword = this_keyword)  
	// Code example for keyword: facets
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: facets
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fade_color";
#if (Keyword = this_keyword)  
	// Code example for keyword: fade_color
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fade_color
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fade_colour";
#if (Keyword = this_keyword)  
	// Code example for keyword: fade_colour
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fade_colour
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fade_distance";
#if (Keyword = this_keyword)  
	// Code example for keyword: fade_distance
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fade_distance
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fade_power";
#if (Keyword = this_keyword)  
	// Code example for keyword: fade_power
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fade_power 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "falloff";
#if (Keyword = this_keyword)  
	// Code example for keyword: falloff 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: falloff 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "falloff_angle";
#if (Keyword = this_keyword)  
	// Code example for keyword: falloff_angle
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: falloff_angle 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "false";
#if (Keyword = this_keyword)  
	// Code example for keyword: false
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: false 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fclose";
#if (Keyword = this_keyword)  
	// Code example for keyword: fclose
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fclose 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "file_exists";
#if (Keyword = this_keyword)  
	// Code example for keyword: file_exists
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: file_exists 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "filter";
#if (Keyword = this_keyword)  
	// Code example for keyword: filter
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: filter 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "final_clock";
#if (Keyword = this_keyword)  
	// Code example for keyword: final_clock
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: final_clock 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "final_frame";
#if (Keyword = this_keyword)  
	// Code example for keyword: final_frame
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: final_frame 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "finish";
#if (Keyword = this_keyword)  
	// Code example for keyword: finish
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: finish 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fisheye";
#if (Keyword = this_keyword)  
	// Code example for keyword: fisheye
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fisheye 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "flatness";
#if (Keyword = this_keyword)  
	// Code example for keyword: flatness
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: flatness 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "flip";
#if (Keyword = this_keyword) 
	// Code example for keyword: flip
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: flip 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	 
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "floor";
#if (Keyword = this_keyword)  
	// Code example for keyword: floor 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by: 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Floor = function (_N) {floor (_N)}
	#for (N, 0, 3, 0.1)
		#debug concat ("floor (", str (N, 0, 2), ") = ", str (Floor(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<5, 4, 0>, P_White, 40)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Floor, 0, 10, 0, 10, 0.01, 0.025) 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "focal_point";
#if (Keyword = this_keyword)  
	// Code example for keyword: focal_point
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: focal_point 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fog";
#if (Keyword = this_keyword)  
	// Code example for keyword: fog 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fog 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fog_alt";
#if (Keyword = this_keyword)  
	// Code example for keyword: fog_alt
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fog_alt 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fog_offset";
#if (Keyword = this_keyword)  
	// Code example for keyword: fog_offset
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fog_offset 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fog_type";
#if (Keyword = this_keyword)  
	// Code example for keyword: fog_type
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fog_type 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fopen";
#if (Keyword = this_keyword)  
	// Code example for keyword: fopen
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fopen 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "for";
#if (Keyword = this_keyword)  
	// Code example for keyword: for 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: for 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "form";
#if (Keyword = this_keyword)  
	// Code example for keyword: form 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: form 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "frame_number";
#if (Keyword = this_keyword)  
	// Code example for keyword: frame_number 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: frame_number 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "frequency";
#if (Keyword = this_keyword)  
	// Code example for keyword: frequency 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: frequency 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "fresnel";
#if (Keyword = this_keyword)  
	// Code example for keyword: fresnel 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: fresnel 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "function ";
#if (Keyword = this_keyword)  
	// Code example for keyword: function  
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: function 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# G #################################################

#declare this_keyword = "gamma";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "gamma bump maps \n"
	#warning " - or - \n"
	#warning "gamma heightfield \n"
	#warning " - or - \n"
	#warning "gamma image map \n"
	#warning " - or - \n"
	#warning "gamma image pattern \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gamma bump maps";
#if (Keyword = this_keyword)  
	// Code example for keyword: gamma bump maps
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gamma bump maps
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gamma heightfield";
#if (Keyword = this_keyword)  
	// Code example for keyword: gamma heightfield 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gamma heightfield 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gamma image map";
#if (Keyword = this_keyword)  
	// Code example for keyword: gamma image map 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gamma image map 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gamma image pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: gamma image pattern 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gamma image pattern 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gather";
#if (Keyword = this_keyword)  
	// Code example for keyword: gather 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gather 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gif";
#if (Keyword = this_keyword)  
	// Code example for keyword: gif
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gif 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "global";
#if (Keyword = this_keyword)  
	// Code example for keyword: global 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: global 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "global_lights";
#if (Keyword = this_keyword)  
	// Code example for keyword: global_lights 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: global_lights 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "global_settings";
#if (Keyword = this_keyword)  
	// Code example for keyword: global_settings 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: global_settings 
	
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gradient ";
#if (Keyword = this_keyword)  
	// Code example for keyword: gradient  
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gradient 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "granite";
#if (Keyword = this_keyword)  
	// Code example for keyword: granite 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: granite 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gray";
#if (Keyword = this_keyword)  
	// Code example for keyword: gray 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gray 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "gray_threshold";
#if (Keyword = this_keyword)  
	// Code example for keyword: gray_threshold 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: gray_threshold 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "green";
#if (Keyword = this_keyword)  
	// Code example for keyword: green 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: green 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# H #################################################

#declare this_keyword = "height_field";
#if (Keyword = this_keyword)  
	// Code example for keyword: height_field 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: height_field 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "hexagon";
#if (Keyword = this_keyword)  
	// Code example for keyword: hexagon 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: hexagon 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "hf_gray_16";
#if (Keyword = this_keyword)  
	// Code example for keyword: hf_gray_16 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: hf_gray_16 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "hierarchy";
#if (Keyword = this_keyword)  
	// Code example for keyword: hierarchy 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: hierarchy 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "hypercomplex";
#if (Keyword = this_keyword)  
	// Code example for keyword: hypercomplex 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: hypercomplex 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "hollow";
#if (Keyword = this_keyword)  
	// Code example for keyword: hollow 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: hollow 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# I #################################################

#declare this_keyword = "if";
#if (Keyword = this_keyword)  
	// Code example for keyword: if 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: if 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ifdef";
#if (Keyword = this_keyword)  
	// Code example for keyword: ifdef 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ifdef 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "iff";
#if (Keyword = this_keyword)  
	// Code example for keyword: iff 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: iff 
	// (image file format)
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ifndef";
#if (Keyword = this_keyword)  
	// Code example for keyword: ifndef
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ifndef
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "image_height";
#if (Keyword = this_keyword)  
	// Code example for keyword: image_height
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: image_height
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "image_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: image_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: image_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "image_pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: image_pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: image_pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "image_width";
#if (Keyword = this_keyword)  
	// Code example for keyword: image_width
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: image_width
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "importance";
#if (Keyword = this_keyword)  
	// Code example for keyword: importance
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: importance
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "include";
#if (Keyword = this_keyword)  
	// Code example for keyword: include
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: include
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "initial_clock";
#if (Keyword = this_keyword)  
	// Code example for keyword: initial_clock
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: initial_clock
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "initial_frame";
#if (Keyword = this_keyword)  
	// Code example for keyword: initial_frame
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: initial_frame
	
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "input_file_name";
#if (Keyword = this_keyword)  
	// Code example for keyword: input_file_name
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: input_file_name
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "inside";
#if (Keyword = this_keyword)  
	// Code example for keyword: inside
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: inside
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "inside_vector";
#if (Keyword = this_keyword)  
	// Code example for keyword: inside_vector
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: inside_vector
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

*/
#declare this_keyword = "int";
#if (Keyword = this_keyword)
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Int = function (_N) {int (_N)}
	#for (N, 0, 3, 0.1)
		#debug concat ("int (", str (N, 0, 2), ") = ", str (Int(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<5, 4, 0>, P_White, 40)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Int, 0, 10, 0, 10, 0.01, 0.025) 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "interior";
#if (Keyword = this_keyword)  
	// Code example for keyword: interior
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: interior
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "interior_texture";
#if (Keyword = this_keyword)  
	// Code example for keyword: interior_texture
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: interior_texture
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "internal";
#if (Keyword = this_keyword)  
	// Code example for keyword: internal
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: internal
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "interpolate";
#if (Keyword = this_keyword)  
	// Code example for keyword: interpolate
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: interpolate
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "intersection";
#if (Keyword = this_keyword) 
	// KEYWORD DISAMBIGUATION BLOCK
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "intersection csg \n"
	#warning " - or - \n"
	#warning "intersection torus \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "intersection csg";
#if (Keyword = this_keyword)  
	// Code example for keyword: intersection csg
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: intersection csg
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "intersection torus";
#if (Keyword = this_keyword)  
	// Code example for keyword: intersection torus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: intersection torus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "intervals";
#if (Keyword = this_keyword)  
	// Code example for keyword: intervals
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: intervals
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "inverse";
#if (Keyword = this_keyword)  
	// Code example for keyword: inverse
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: inverse
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ior";
#if (Keyword = this_keyword)  
	// Code example for keyword: ior
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ior
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "irid";
#if (Keyword = this_keyword)  
	// Code example for keyword: irid
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: irid
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "irid_wavelength";
#if (Keyword = this_keyword)  
	// Code example for keyword: irid_wavelength
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: irid_wavelength
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  


// -----------------------------------------------------------------------------------------------------
*/

#declare this_keyword = "isosurface";
#if (Keyword = this_keyword)  
	// Code example for keyword: isosurface
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	// ********** WORK IN PROGRESS **********
	#declare Gradient = 10;
	#declare Min_factor= 0.7;
	
	#include "functions.inc"
	// The central sphere
	#declare SS = function (X, Y, Z) {pow(X,2)+pow(Y,2)+pow(Z,2) - 0.0625}
	// a 90-deg rotation around x to bring the following tori into the xy plane
	#declare TR1 = transform {rotate x*90}
	#declare TI1 = function {transform {TR1 inverse}}
	// The outer torus of the "P"
	#declare T1 = function (X, Y, Z) {f_torus (X, Y, Z, 0.6, 0.1)}
	// The inner torus of the "P"
	#declare T2 = function (X, Y, Z) {f_torus (X*1.05+0.0525, Y*1.2, Z*1.2, 0.6, 0.13)}
	// a -25-deg rotation around z to tilt the cone
	#declare TR2 = transform {rotate -z*25}
	#declare TI2 = function {transform {TR2 inverse}}
	// The cone of the "P"
	#declare C = function (X, Y, Z) {
	max (sqrt(pow(X*7,2) + pow(Z*7,2)*2) - (Y+1.75), Y )
	}
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<0, 0, 0>, pigment {rgb 1}, 150)
	
	#declare Logo = 
	function {
		min (
			SS (x,y,z), 
			max (
			T1 (TI1 (x,y,z).x, TI1 (x,y,z).y, TI1 (x,y,z).z),
			-T2 (TI1 (x,y,z).x, TI1 (x,y,z).y, TI1 (x,y,z).z)
			),
			C  (TI2 (x,y,z).x, TI2 (x,y,z).y, TI2 (x,y,z).z)
		)
	}
	isosurface {
		function {Logo (x, y, z)}
		threshold 0
		evaluate Gradient*Min_factor,  sqrt(Gradient/(Gradient*Min_factor)),  min (0.7, 1.0)
		accuracy     0.0001
		contained_by {box {<-1, -1, -1>*2, <1, 1.2, 1>*2}}
		texture {pigment {rgb <0, 0, 0.2>} finish {specular 0.2}} interior_texture {pigment {agate} finish {specular 0.4}}
		translate y*0.5
		
	} 
	text {ttf "timrom.ttf", "POV-Ray Logo as an isosurface {} object", 0.01, 0.0 scale 0.125 translate <-1, -1.5, 0> pigment {rgb 0}}
	
#end

// -----------------------------------------------------------------------------------------------------


// ################################################# J #################################################

#declare this_keyword = "jitter";
#if (Keyword = this_keyword)  
	// Code example for keyword: jitter
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: jitter
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	/*
	(area lights)
	The jitter keyword is optional. When used it causes the positions of the point lights in the array 
	to be randomly jittered to eliminate any shadow banding that may occur. The jittering is completely 
	random from render to render and should not be used when generating animations.
	(photons)
	The keyword jitter specifies the amount of jitter used in the sampling of light rays in the pre-processing step. 
	The default value is good and usually does not need to be changed.
	(media)
	jitter also works with method 3.
	jitter will cause method 2 to look similar to method 1. It should be followed by a float, and a value of 1 
	will stagger the samples in the full range between samples.
	*/
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "jpeg";
#if (Keyword = this_keyword)  
	// Code example for keyword: jpeg
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: jpeg
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "julia";
#if (Keyword = this_keyword)  
	// Code example for keyword: julia
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: julia
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "julia_fractal";
#if (Keyword = this_keyword)  
	// Code example for keyword: julia_fractal
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: julia_fractal
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# K #################################################

// ################################################# L #################################################

#declare this_keyword = "lambda";
#if (Keyword = this_keyword)  
	// Code example for keyword: lambda
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: lambda
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "lathe";
#if (Keyword = this_keyword)  
	// Code example for keyword: lathe
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: lathe
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "lemon";
#if (Keyword = this_keyword)  
	// Code example for keyword: lemon
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: lemon
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "leopard";
#if (Keyword = this_keyword)  
	// Code example for keyword: leopard
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: leopard
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "light_group";
#if (Keyword = this_keyword)  
	// Code example for keyword: light_group
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: light_group
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "light_source";
#if (Keyword = this_keyword)  
	// Code example for keyword: light_source
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: light_source
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "linear_spline";
#if (Keyword = this_keyword)  
	// Code example for keyword: linear_spline
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: linear_spline
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "linear_sweep";
#if (Keyword = this_keyword)  
	// Code example for keyword: linear_sweep
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: linear_sweep
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "ln";
#if (Keyword = this_keyword)
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Ln = function (_N) {ln (_N)}
	#for (N, 0, 3, 0.1)
		#debug concat ("ln (", str (N, 0, 2), ") = ", str (Ln(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<5, 4, 0>, P_White, 40)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Ln, 0, 10, 0, 10, 0.01, 0.025) 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "load_file";
#if (Keyword = this_keyword)  
	// Code example for keyword: load_file
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: load_file
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "local directive";
#if (Keyword = this_keyword)  
	// Code example for keyword: local directive
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: local directive
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "local dictionary";
#if (Keyword = this_keyword)  
	// Code example for keyword: local dictionary
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: local dictionary
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "location";
#if (Keyword = this_keyword)  
	// Code example for keyword: location
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: location
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "log";
#if (Keyword = this_keyword)
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Log = function (_N) {log (_N)}
	#for (N, 0, 3, 0.1)
		#debug concat ("log (", str (N, 0, 2), ") = ", str (Log(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<5, 4, 0>, P_White, 40)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Log, 0, 10, 0, 10, 0.01, 0.025) 
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "look_at";
#if (Keyword = this_keyword)  
	// Code example for keyword: look_at
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: look_at
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "looks_like";
#if (Keyword = this_keyword)  
	// Code example for keyword: looks_like
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: looks_like
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "low_error_factor";
#if (Keyword = this_keyword)  
	// Code example for keyword: low_error_factor
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: low_error_factor
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// ################################################# M #################################################

#declare this_keyword = "macro";
#if (Keyword = this_keyword)  
	// Code example for keyword: macro
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: macro
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "magnet";
#if (Keyword = this_keyword)  
	// Code example for keyword: magnet
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: magnet
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "major_radius";
#if (Keyword = this_keyword)  
	// Code example for keyword: major_radius
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: major_radius
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "mandel";
#if (Keyword = this_keyword)  
	// Code example for keyword: mandel
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	
	// Code example for keyword: mandel
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "map_type";
#if (Keyword = this_keyword)  
	// Code example for keyword: map_type
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: map_type
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "marble";
#if (Keyword = this_keyword)  
	// Code example for keyword: marble
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: marble
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "material";
#if (Keyword = this_keyword)  
	// Code example for keyword: material
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: material
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "material_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: material_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: material_map 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "matrix";
#if (Keyword = this_keyword)  
	// Code example for keyword: matrix 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: matrix
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "max";
#if (Keyword = this_keyword)  
	// Code example for keyword: max 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	// Maximum of two or more float values. Returns A if A larger than B. Otherwise returns B.
	//
	// Example code notes:   Take some max's of some random numbers
	#local MaxSeed = seed (1928);
	#local Mult = 7;
	#for (N, 2, 5)
		#local Narray = array;
		#for (NN, 0, N-1)
			#local Narray [NN] = rand (MaxSeed) * Mult;
		#end
		#local ND = dimension_size (Narray, 1)-1;
		#local Max = 0;
		#debug concat ("max (", 
			#for (NN, 0, ND)
				str (Narray [NN], 0, 3), 
				#if (NN < ND) ", ", #end
				#local Max = max (Narray [NN], Max);
			#end
			") = ", str (Max, 0, 3)
		"\n")
	#end
	#error NO	// Stop render
	/*
	See also in math.inc
	max3 = function (x, y, z) {max(x,y,z)}
	VMax(V) (max3(V.x, V.y, V.z))
	*/
#end  


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "maximum_reuse";
#if (Keyword = this_keyword)  
	// Code example for keyword: maximum_reuse
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: maximum_reuse
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "max_extent";
#if (Keyword = this_keyword)  
	// Code example for keyword: max_extent
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: max_extent
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "max_gradient";
#if (Keyword = this_keyword)  
	// Code example for keyword: max_gradient
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: max_gradient
	/*
	POV-Ray can find the first intersecting point between a ray and the isosurface of any continuous function 
	if the maximum gradient of the function is known. Therefore you can specify a max_gradient for the function. 
	The default value is 1.1. When the max_gradient used to find the intersecting point is too high, the render 
	slows down considerably. When it is too low, artefacts or holes may appear on the isosurface. 
	When it is way too low, the surface does not show at all. While rendering the isosurface POV-Ray records the 
	found gradient values and prints a warning if these values are higher or much lower than the specified max_gradient
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
#end  

// -----------------------------------------------------------------------------------------------------



#declare this_keyword = "max_intersections";
#if (Keyword = this_keyword)  
	// Code example for keyword: max_intersections
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: max_intersections
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "max_iteration";
#if (Keyword = this_keyword)  
	// Code example for keyword: max_iteration
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: max_iteration
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "max_sample";
#if (Keyword = this_keyword)  
	// Code example for keyword: max_sample
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: max_sample
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "max_trace";
#if (Keyword = this_keyword)  
	// Code example for keyword: max_trace
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: max_trace
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	// Isosurfaces can be used in CSG shapes since they are solid finite objects - if not finite by themselves, 
	// they are through the cross section with the container.
	// By default POV-Ray searches only for the first surface which the ray intersects. But when using an isosurface 
	// in CSG operations, the other surfaces must also be found. Therefore, the keyword max_trace must be added to 
	// the isosurface statement. It must be followed by an integer value.
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "max_trace_level";
#if (Keyword = this_keyword)  
	// Code example for keyword: max_trace_level
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: max_trace_level
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "media";
#if (Keyword = this_keyword)  
	// Code example for keyword: media
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: media
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "media_attenuation";
#if (Keyword = this_keyword)  
	// Code example for keyword: media_attenuation
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: media_attenuation
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "media_interaction";
#if (Keyword = this_keyword)  
	// Code example for keyword: media_interaction
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: media_interaction
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "merge";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "merge csg \n"
	#warning " - or - \n"
	#warning "merge torus \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "merge csg";
#if (Keyword = this_keyword)  
	// Code example for keyword: merge csg
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: merge csg
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "merge torus";
#if (Keyword = this_keyword)  
	// Code example for keyword: merge torus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: merge torus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "mesh";
#if (Keyword = this_keyword)  
	// Code example for keyword: mesh
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: mesh
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "mesh2";
#if (Keyword = this_keyword)  
	// Code example for keyword: mesh2
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: mesh2
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "metallic";
#if (Keyword = this_keyword)  
	// Code example for keyword: metallic
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: metallic
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "method";
#if (Keyword = this_keyword)  
	// Code example for keyword: method
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: method
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "metric";
#if (Keyword = this_keyword)  
	// Code example for keyword: metric
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: metric
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

*/

#declare this_keyword = "min";
#if (Keyword = this_keyword)  
	// Code example for keyword: max 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	// Minimum of two or more float values. Returns A if A smaller than B. Otherwise returns B.
	//
	// Example code notes:   Take some min's of some random numbers
	#local MinSeed = seed (1928);
	#local Mult = 9;
	#for (N, 2, 5)
		#local Narray = array;
		#for (NN, 0, N-1)
			#local Narray [NN] = rand (MinSeed) * Mult;
		#end
		#local ND = dimension_size (Narray, 1)-1;
		#local Min = 10;
		#debug concat ("min (", 
			#for (NN, 0, ND)
				str (Narray [NN], 0, 3), 
				#if (NN < ND) ", ", #end
				#local Min = min (Narray [NN], Min);
			#end
			") = ", str (Min, 0, 3)
		"\n")
	#end
	#error NO	// Stop render
	/*
	See also in math.inc
	max3 = function (x, y, z) {max(x,y,z)}
	VMax(V) (max3(V.x, V.y, V.z))
	*/
#end  
	
 



// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "min_extent";
#if (Keyword = this_keyword)  
	// Code example for keyword: min_extent
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: min_extent
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "minimum_reuse";
#if (Keyword = this_keyword)  
	// Code example for keyword: minimum_reuse
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: minimum_reuse
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "mixed";
#if (Keyword = this_keyword)  
	// Code example for keyword: mixed
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: mixed
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "mm_per_unit";
#if (Keyword = this_keyword)  
	// Code example for keyword: mm_per_unit
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: mm_per_unit
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "mod";
#if (Keyword = this_keyword)
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Mod = function (_N) {mod (_N)}
	#for (N, 0, 3, 0.1)
		#debug concat ("mod (", str (N, 0, 2), ") = ", str (Mod(N), 0, 4), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (<5, 4, 0>, P_White, 40)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Mod, 0, 10, 0, 10, 0.01, 0.025) 
#end 
 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "mortar";
#if (Keyword = this_keyword)  
	// Code example for keyword: mortar
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: mortar
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# N #################################################

#declare this_keyword = "natural_spline";
#if (Keyword = this_keyword)  
	// Code example for keyword: natural_spline
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: natural_spline
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "nearest_count";
#if (Keyword = this_keyword)  
	// Code example for keyword: nearest_count
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: nearest_count
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "no";
#if (Keyword = this_keyword)  
	// Code example for keyword: no
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: no
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "no_bump_scale";
#if (Keyword = this_keyword)  
	// Code example for keyword: no_bump_scale
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: no_bump_scale
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "no_image";
#if (Keyword = this_keyword)  
	// Code example for keyword: no_image
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: no_image
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "no_radiosity";
#if (Keyword = this_keyword)  
	// Code example for keyword: no_radiosity
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: no_radiosity
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "no_reflection";
#if (Keyword = this_keyword)  
	// Code example for keyword: no_reflection
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: no_reflection
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "no_shadow";
#if (Keyword = this_keyword)  
	// Code example for keyword: no_shadow
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: no_shadow
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "noise_generator";
#if (Keyword = this_keyword)  
	// Code example for keyword: noise_generator
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: noise_generator
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
	#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "normal";
#if (Keyword = this_keyword)  
	// Code example for keyword: normal
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: normal 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "normal_indices";
#if (Keyword = this_keyword)  
	// Code example for keyword: normal_indices
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: normal_indices
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "normal_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: normal_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: normal_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "normal_vectors";
#if (Keyword = this_keyword)  
	// Code example for keyword:
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: normal_vectors
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "now";
#if (Keyword = this_keyword)  
	// Code example for keyword: now now #end  
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#declare WhoWhen = concat ("The current time is: ", datetime (now-(5/24), "%Y-%m-%d %H:%M") );
	#error NO	// Stop render
	/*
	now is an internal value that returns a date code
	*/
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "number_of_waves";
#if (Keyword = this_keyword)  
	// Code example for keyword: number_of_waves
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: number_of_waves
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// ################################################# O #################################################

#declare this_keyword = "object";
#if (Keyword = this_keyword)  
	// Code example for keyword:
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: object
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "octaves";
#if (Keyword = this_keyword)  
	// Code example for keyword: octaves
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: octaves
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "off";
#if (Keyword = this_keyword)  
	// Code example for keyword: off
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: off 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "offset";
#if (Keyword = this_keyword)  
	// Code example for keyword: offset
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: offset
	
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "omega";
#if (Keyword = this_keyword)  
	// Code example for keyword:omega
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: omega
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "omnimax";
#if (Keyword = this_keyword)  
	// Code example for keyword: omnimax
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: omnimax
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "on";
#if (Keyword = this_keyword)  
	// Code example for keyword: on
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: on
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "once";
#if (Keyword = this_keyword)  
	// Code example for keyword: once
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: once
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "onion";
#if (Keyword = this_keyword)  
	// Code example for keyword: onion
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: onion
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "open";
#if (Keyword = this_keyword)  
	// Code example for keyword:
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	
	// Code example for keyword: open 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	// When the isosurface is not fully contained within the contained_by object, there will be a cross section. 
	// Where this happens, you will see the surface of the container. With the open keyword, these cross section 
	// surfaces are removed. The inside of the isosurface becomes visible.
	// Note: that open slows down the render speed. Also, it is not recommended to use it with CSG operations.
#end 

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "optional"; 
#if (Keyword = this_keyword)  
	// Code example for keyword: optional
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: optional
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "orient";
#if (Keyword = this_keyword)  
	// Code example for keyword: orient
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: orient
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "orientation";
#if (Keyword = this_keyword)  
	// Code example for keyword: orientation
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: orientation
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "orthographic";
#if (Keyword = this_keyword)  
	// Code example for keyword: orthographic
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: orthographic
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ovus";
#if (Keyword = this_keyword)  
	// Code example for keyword: ovus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ovus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# P #################################################

#declare this_keyword = "panoramic";
#if (Keyword = this_keyword)  
	// Code example for keyword: panoramic
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: panoramic
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "parallel";
#if (Keyword = this_keyword)  
	// Code example for keyword: parallel
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: parallel
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "parametric";
#if (Keyword = this_keyword)  
	// Code example for keyword: parametric
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: parametric
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pass_through";
#if (Keyword = this_keyword)  
	// Code example for keyword: pass_through
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pass_through
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  
---------------------------------------------------------------------------------------------------

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pavement";
#if (Keyword = this_keyword)  
	// Code example for keyword: pavement
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pavement
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "perspective";
#if (Keyword = this_keyword)  
	// Code example for keyword: perspective
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: perspective
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pgm";
#if (Keyword = this_keyword)  	
	// Code example for keyword: pgm
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pgm 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "phase";
#if (Keyword = this_keyword)  	
	// Code example for keyword: phase
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: phase 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "phong";
#if (Keyword = this_keyword)  	
	// Code example for keyword: phong
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: phong
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "phong_size";
#if (Keyword = this_keyword)  	
	// Code example for keyword: phong_size
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: phong_size
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "photons";
#if (Keyword = this_keyword)  
	// Code example for keyword: photons
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: photons
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pi";
#if (Keyword = this_keyword)  // Code example for keyword: pi pi #end  
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	// the ratio of the circumference of any circle to the diameter of that circle
	// 3.141592653589793238...
	// the area of a circle is equal to pi times the radius squared
	#debug concat ("pi = ", str (pi, 0, 40), "...", " \n")
	#error NO	// Stop render
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pigment";
#if (Keyword = this_keyword)  
	// Code example for keyword: pigment
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pigment
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pigment_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: pigment_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pigment_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pigment_pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: pigment_pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pigment_pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "planar";
#if (Keyword = this_keyword)  
	// Code example for keyword: planar
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: planar
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "plane";
#if (Keyword = this_keyword)  
	// Code example for keyword: plane
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: plane
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "png";
#if (Keyword = this_keyword)  
	// Code example for keyword: png
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: png
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "point_at";
#if (Keyword = this_keyword)  
	// Code example for keyword: point_at
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: point_at
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "polarity";
#if (Keyword = this_keyword)  
	// Code example for keyword: polarity
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: polarity
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "poly";
#if (Keyword = this_keyword)  
	// Code example for keyword: poly
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: poly
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "polynomial";
#if (Keyword = this_keyword)  
	// Code example for keyword: polynomial 
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")

	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (0, P_White, 20)
	// caption: Rabinowitz constant-width polynomial
	intersection {
		polynomial {
		8,
		xyz(8,0,0): 1,
		xyz(7,0,0): 16,
		xyz(6,0,0): 19,
		xyz(6,2,0): 4,
		xyz(5,0,0):-5544,
		xyz(5,2,0):-16,
		xyz(4,0,0):-41283,
		xyz(4,4,0): 6,
		xyz(4,2,0):-519,
		xyz(3,0,0): 266382,
		xyz(3,4,0):-80,
		xyz(3,2,0): 11088,
		xyz(2,0,0): 7950960,
		xyz(2,6,0): 4,
		xyz(2,4,0): 441,
		xyz(2,2,0):-82566,
		xyz(1,6,0):-48,
		xyz(1,4,0): 16632,
		xyz(1,2,0):-799146,
		xyz(0,2,0): 7950960,
		xyz(0,4,0):-41283,
		xyz(0,6,0):-45,
		xyz(0,8,0): 1,
		xyz(0,0,0):-373248000
		
		sturm
		}
		box {<-50, -50, -0.1> <50, 50, 0.1>}
		pigment {rgb <0, 0, 0.5>}
	}
	/*
	
	*/
#end  


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "poly_wave";
#if (Keyword = this_keyword)  
	// Code example for keyword: poly_wave
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: poly_wave
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "polygon";
#if (Keyword = this_keyword) 
	// Code example for keyword: polygon
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: polygon
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pot";
#if (Keyword = this_keyword)  
	// Code example for keyword: pot
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pot
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "potential";
#if (Keyword = this_keyword)  
	// Code example for keyword: potential
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: potential
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------


#declare this_keyword = "pow";
#if (Keyword = this_keyword)  
	// Code example for keyword: pow
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	/* 
	
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#local Pow = function (_N, _P) {pow (_N, _P)}
	#for (P, 0, 8, 1)
		#debug concat ("pow (2, ", str (P, 4, 0), ") = ", str (Pow(2, P), 4, 0), " \n")
	#end
	//#error NO	// Stop render
	//OrthoScene (Center, SkySphereColor, Zoom)
	OrthoScene (y*pi/2, P_White, 130)
	//GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	GraphLinearEquation (Pow, -1, 1, 0, pi, pi/90, 0.01)

	/*
	Coding syntax notes:

	*/
#end 


// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ppm";
#if (Keyword = this_keyword)  
	// Code example for keyword: ppm
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ppm 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "precision julia";
#if (Keyword = this_keyword)  
	// Code example for keyword: precision julia
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: precision julia
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "precision ovus";
#if (Keyword = this_keyword)  
	// Code example for keyword: precision ovus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: precision ovus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "precompute";
#if (Keyword = this_keyword)  
	// Code example for keyword: precompute
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: precompute
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "premultiplied";
#if (Keyword = this_keyword)  
	// Code example for keyword: premultiplied
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: premultiplied
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pretrace_end";
#if (Keyword = this_keyword)  
	// Code example for keyword: pretrace_end
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pretrace_end
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pretrace_start";
#if (Keyword = this_keyword)  
	// Code example for keyword: pretrace_start
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pretrace_start
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "prism";
#if (Keyword = this_keyword)  
	// Code example for keyword: prism
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: prism
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "prod";
#if (Keyword = this_keyword)  
	// Code example for keyword: prod
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: prod
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "projected_through";
#if (Keyword = this_keyword)  
	// Code example for keyword: projected_through
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: projected_through
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "pwr";
#if (Keyword = this_keyword) 
	// Code example for keyword: pwr
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: pwr
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# Q #################################################

#declare this_keyword = "quadratic_spline";
#if (Keyword = this_keyword)  
	// Code example for keyword: quadratic_spline
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: quadratic_spline
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "quadric";
#if (Keyword = this_keyword)  
	// Code example for keyword: quadric
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: quadric
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "quartic";
#if (Keyword = this_keyword)  
	// Code example for keyword: quartic
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: quartic
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "quaternion";
#if (Keyword = this_keyword)  
	// Code example for keyword: quaternion
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: quaternion
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "quick_color";
#if (Keyword = this_keyword)  
	// Code example for keyword: quick_color
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: quick_color
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "quick_colour";
#if (Keyword = this_keyword)  
	// Code example for keyword: quick_colour
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: quick_colour
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "quilted";
#if (Keyword = this_keyword)  
	// Code example for keyword: quilted
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: quilted
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# R #################################################

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "radial";
#if (Keyword = this_keyword)  
	// Code example for keyword: radial
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: radial
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "radians";
#if (Keyword = this_keyword)  
	// Code example for keyword: radians
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: radians
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "radiosity";
#if (Keyword = this_keyword)  
	// Code example for keyword: radiosity
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: radiosity
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "radius spotlight";
#if (Keyword = this_keyword)  
	// Code example for keyword: radius spotlight
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: radius spotlight
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "radius ovus";
#if (Keyword = this_keyword)  
	// Code example for keyword: radius ovus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: radius ovus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "rainbow";
#if (Keyword = this_keyword)  
	// Code example for keyword: rainbow
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: rainbow
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ramp_wave";
#if (Keyword = this_keyword)  
	// Code example for keyword: ramp_wave
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ramp_wave
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "rand";
#if (Keyword = this_keyword)  
	// Code example for keyword: rand
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: rand
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "range";
#if (Keyword = this_keyword)  
	// Code example for keyword: range
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: range
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ratio";
#if (Keyword = this_keyword)  
	// Code example for keyword: ratio
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ratio
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "read";
#if (Keyword = this_keyword)  
	// Code example for keyword: read
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: read
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "reciprocal";
#if (Keyword = this_keyword)  
	// Code example for keyword: reciprocal
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: reciprocal
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "recursion_limit";
#if (Keyword = this_keyword)  
	// Code example for keyword: recursion_limit
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: recursion_limit
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "red";
#if (Keyword = this_keyword)  
	// Code example for keyword: red
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: red
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "reflection";
#if (Keyword = this_keyword)  
	// Code example for keyword: reflection
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: reflection
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "reflection_exponent";
#if (Keyword = this_keyword)  
	// Code example for keyword: reflection_exponent
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: reflection_exponent
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "refraction";
#if (Keyword = this_keyword)  
	// Code example for keyword:
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: refraction
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "render";
#if (Keyword = this_keyword)  
	// Code example for keyword: render
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: render
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "repeat";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "repeat crackle pattern \n"
	#warning " - or - \n"
	#warning "repeat warp \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "repeat crackle pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: repeat crackle pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: repeat crackle pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "repeat warp";
#if (Keyword = this_keyword)  
	// Code example for keyword: repeat warp
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: repeat warp
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "rgb";
#if (Keyword = this_keyword)  
	// Code example for keyword: rgb
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: rgb
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "rgbf";
#if (Keyword = this_keyword)  
	// Code example for keyword: rgbf
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: rgbf
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "rgbft";
#if (Keyword = this_keyword)  
	// Code example for keyword: rgbft
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: rgbft
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "rgbt";
#if (Keyword = this_keyword)  
	// Code example for keyword: rgbt
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: rgbt
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "right";
#if (Keyword = this_keyword)  
	// Code example for keyword: right
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: right
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ripples";
#if (Keyword = this_keyword)  
	// Code example for keyword: ripples
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ripples
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "rotate";
#if (Keyword = this_keyword)  
	// Code example for keyword: rotate
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: rotate 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "roughness";
#if (Keyword = this_keyword)  
	// Code example for keyword: roughness
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: roughness 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# S #################################################

#declare this_keyword = "samples media";
#if (Keyword = this_keyword)  
	// Code example for keyword: samples media
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: samples media 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "samples subsurface ";
#if (Keyword = this_keyword)  
	// Code example for keyword: samples subsurface 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: samples subsurface 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "save_file";
#if (Keyword = this_keyword)  
	// Code example for keyword: save_file
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: save_file 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "scale";
#if (Keyword = this_keyword)  
	// Code example for keyword: scale
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: scale 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "scallop_wave ";
#if (Keyword = this_keyword)  
	// Code example for keyword: scallop_wave 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: scallop_wave 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "scattering";
#if (Keyword = this_keyword)  
	// Code example for keyword: scattering
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: scattering
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "seed";
#if (Keyword = this_keyword)  
	// Code example for keyword: seed
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: seed
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "select";
#if (Keyword = this_keyword)  
	// Code example for keyword: select
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: select
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "shadowless";
#if (Keyword = this_keyword)  
	// Code example for keyword: shadowless
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: shadowless
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sin";
#if (Keyword = this_keyword)  
	// Code example for keyword: sin
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sin 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sine_wave ";
#if (Keyword = this_keyword)  
	// Code example for keyword: sine_wave 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sine_wave 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sinh";
#if (Keyword = this_keyword)  
	// Code example for keyword: sinh
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sinh 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sint8";
#if (Keyword = this_keyword)  
	// Code example for keyword: sint8
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sint8 
	/*
	sint8              - signed byte (-128..127)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sint16be";
#if (Keyword = this_keyword)  
	// Code example for keyword: sint16be
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sint16be 
	/*
	sint16be, sint16le - signed 16-bit word (-32768..32767)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sint16le";
#if (Keyword = this_keyword)  
	// Code example for keyword: sint16le
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sint16le 
	/*
	sint16be, sint16le - signed 16-bit word (-32768..32767)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sint32be";
#if (Keyword = this_keyword)  
	// Code example for keyword: sint32be
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sint32be 
	/*
	sint32be, sint32le - signed 32-bit word (-2^31..2^31-1)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	Note: Currently, unsigned 32-bit words are not supported.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sint32le";
#if (Keyword = this_keyword)  
	// Code example for keyword: sint32le
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sint32le 
	/*
	sint32be, sint32le - signed 32-bit word (-2^31..2^31-1)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	Note: Currently, unsigned 32-bit words are not supported.
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "size";
#if (Keyword = this_keyword)  
	// Code example for keyword: size
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: size 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sky";
#if (Keyword = this_keyword)  
	// Code example for keyword: sky
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sky
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sky_sphere";
#if (Keyword = this_keyword)  
	// Code example for keyword: sky_sphere
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sky_sphere 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "slice";
#if (Keyword = this_keyword)  
	// Code example for keyword: slice
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: slice
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "slope";
#if (Keyword = this_keyword) 
	// Code example for keyword: slope
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: slope
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "slope_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: slope_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: slope_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "smooth";
#if (Keyword = this_keyword)  
	// Code example for keyword: smooth
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: smooth
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "smooth_triangle";
#if (Keyword = this_keyword)  	
	// Code example for keyword: smooth_triangle
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "solid";
#if (Keyword = this_keyword)  
	// Code example for keyword: solid
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: solid
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sor";
#if (Keyword = this_keyword)  
	// Code example for keyword: sor
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sor
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "spacing";
#if (Keyword = this_keyword)  
	// Code example for keyword: spacing
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: spacing
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "specular";
#if (Keyword = this_keyword)  
	// Code example for keyword: specular
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: specular
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sphere";
#if (Keyword = this_keyword)  
	// Code example for keyword: sphere
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sphere
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sphere_sweep";
#if (Keyword = this_keyword) 
	// Code example for keyword: sphere_sweep
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sphere_sweep
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "spherical";
#if (Keyword = this_keyword)  
	// Code example for keyword: spherical
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: spherical
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "spiral1";
#if (Keyword = this_keyword)  
	// Code example for keyword: spiral1
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: spiral1
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "spiral2";
#if (Keyword = this_keyword)  
	// Code example for keyword: spiral2
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: spiral2
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "spline";
#if (Keyword = this_keyword)  
	// Code example for keyword: spline
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: spline
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "split_union";
#if (Keyword = this_keyword)  
	// Code example for keyword: split_union
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: split_union
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "spotlight";
#if (Keyword = this_keyword)  
	// Code example for keyword: spotlight
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: spotlight
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "spotted";
#if (Keyword = this_keyword)  
	// Code example for keyword: spotted
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: spotted
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sqr";
#if (Keyword = this_keyword)  
	// Code example for keyword: sqr
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sqr
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sqrt";
#if (Keyword = this_keyword)  
	// Code example for keyword: sqrt
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sqrt
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "square";
#if (Keyword = this_keyword)  
	// Code example for keyword: square
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: square
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgb";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "srgb bump maps \n"
	#warning " - or - \n"
	#warning "srgb color literals \n"
	#warning " - or - \n"
	#warning "srgb heightfield \n"
	#warning " - or - \n"
	#warning "srgb image maps \n"
	#warning " - or - \n"
	#warning "srgb image pattern \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgb bump maps";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgb bump maps
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgb bump maps
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgb color literals";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgb color literals
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgb color literals
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgb heightfield";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgb heightfield
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgb heightfield
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgb image maps";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgb image maps
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgb image maps
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgb image pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgb image pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgb image pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgbf";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgbf
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgbf
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgbt";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgbt
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgbt
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "srgbft";
#if (Keyword = this_keyword)  
	// Code example for keyword: srgbft
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: srgbft
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "statistics";
#if (Keyword = this_keyword)  
	// Code example for keyword: statistics
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: statistics
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "str";
#if (Keyword = this_keyword)  
	// Code example for keyword: str
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: str
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "strcmp";
#if (Keyword = this_keyword)  
	// Code example for keyword: strcmp
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: strcmp
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "strength";
#if (Keyword = this_keyword)  
	// Code example for keyword: strength
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: strength
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "strlen";
#if (Keyword = this_keyword)  
	// Code example for keyword: strlen
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: strlen
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "strlwr";
#if (Keyword = this_keyword)  
	// Code example for keyword: strlwr
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: strlwr
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "strupr";
#if (Keyword = this_keyword)  
	// Code example for keyword: strupr
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: strupr
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sturm";
#if (Keyword = this_keyword)  
	// Code example for keyword: sturm
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sturm
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "substr";
#if (Keyword = this_keyword)  
	// Code example for keyword: substr
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: substr
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "subsurface";
#if (Keyword = this_keyword)  
	// Code example for keyword: subsurface
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: subsurface
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sum";
#if (Keyword = this_keyword)  
	// Code example for keyword: sum
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sum
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "superellipsoid";
#if (Keyword = this_keyword)  
	// Code example for keyword: superellipsoid
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: superellipsoid
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "switch";
#if (Keyword = this_keyword)  
	// Code example for keyword: switch
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: switch
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "sys";
#if (Keyword = this_keyword)  
	// Code example for keyword: sys
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: sys
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# T #################################################

#declare this_keyword = "t";
#if (Keyword = this_keyword)  
	// Code example for keyword: t
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: t
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tan";
#if (Keyword = this_keyword)  
	// Code example for keyword: tan
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tan
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tanh";
#if (Keyword = this_keyword)  
	// Code example for keyword: tanh
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tanh 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "target";
#if (Keyword = this_keyword)  
	// Code example for keyword: target
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: target 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tau";
#if (Keyword = this_keyword)  
	// Code example for keyword: tau
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tau 
	tau 
	
#end  
#debug concat ("tau = ", str (tau, 0, 40), "...", " \n")

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "text";
#if (Keyword = this_keyword)  
	// Code example for keyword: text
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: text 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "texture";
#if (Keyword = this_keyword) 
	// Code example for keyword: texture
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: texture 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "texture_list";
#if (Keyword = this_keyword)  
	// Code example for keyword: texture_list
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: texture_list
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "texture_map";
#if (Keyword = this_keyword)  
	// Code example for keyword: texture_map
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: texture_map
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tga";
#if (Keyword = this_keyword)  
	// Code example for keyword: tga
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tga
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "thickness";
#if (Keyword = this_keyword)  
	// Code example for keyword: thickness
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: thickness
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "threshold";
#if (Keyword = this_keyword) 
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "threshold blob \n"
	#warning " - or - \n"
	#warning "threshold isosurface \n"
	#warning " - or - \n"
	#warning "threshold potential pattern \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "threshold blob ";
#if (Keyword = this_keyword)  
	// Code example for keyword: threshold blob 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	
	// Code example for keyword: threshold blob 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "threshold isosurface";
#if (Keyword = this_keyword) 	
// Code example for keyword:
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	 
	// Code example for keyword: threshold isosurface 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	// This specifies how much strength, or substance to give the isosurface. 
	// The surface appears where the function value equals the threshold value. 
	// The default threshold is 0.
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "threshold potential pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: threshold potential pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	
	// Code example for keyword: threshold potential pattern 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tiff";
#if (Keyword = this_keyword)  
	// Code example for keyword: tiff
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tiff 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tightness";
#if (Keyword = this_keyword)  
	// Code example for keyword: tightness
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tightness
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tile2";
#if (Keyword = this_keyword)  
	// Code example for keyword: tile2
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tile2
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tiles";
#if (Keyword = this_keyword) 
	// Code example for keyword: tiles
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tiles
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tiling";
#if (Keyword = this_keyword)  
	// Code example for keyword: tiling
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tiling
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "tolerance";
#if (Keyword = this_keyword)  
	// Code example for keyword: tolerance
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: tolerance
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "toroidal";
#if (Keyword = this_keyword)  
	// Code example for keyword: toroidal
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: toroidal 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "torus";
#if (Keyword = this_keyword)  
	// Code example for keyword: torus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: torus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "trace";
#if (Keyword = this_keyword)  
	// Code example for keyword: trace
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: trace
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "transform";
#if (Keyword = this_keyword) 
	// Code example for keyword: transform
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: transform
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "translate";
#if (Keyword = this_keyword)  
	// Code example for keyword: translate
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: translate
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "translucency";
#if (Keyword = this_keyword)  
	// Code example for keyword: translucency 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: translucency
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	 
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "transmit";
#if (Keyword = this_keyword)  
	// Code example for keyword: transmit
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: transmit
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "triangle"; 
#if (Keyword = this_keyword)  
	// Code example for keyword: triangle
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: triangle
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "triangle_wave"; 
#if (Keyword = this_keyword)  
	// Code example for keyword: triangle_wave
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: triangle_wave
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "triangular";
#if (Keyword = this_keyword)  
	// Code example for keyword: triangular
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: triangular
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "true";
#if (Keyword = this_keyword)  
	// Code example for keyword: true
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: true
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ttf";
#if (Keyword = this_keyword)  
	// Code example for keyword: ttf
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ttf
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "turb_depth";
#if (Keyword = this_keyword)  
	// Code example for keyword: turb_depth
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: turb_depth
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "turbulence";
#if (Keyword = this_keyword)  
	// Code example for keyword: turbulence
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: turbulence
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "type";
#if (Keyword = this_keyword)  
	// Code example for keyword: type
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: type
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# U #################################################

#declare this_keyword = "u";
#if (Keyword = this_keyword)  
	// Code example for keyword: u
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: u
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "uint8";
#if (Keyword = this_keyword)  
	// Code example for keyword: uint8
	// Version 0.1
	// Author: Tor Olav Kristensen
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: uint8
	/*
	uint8              - unsigned byte (0..255)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	*/
	#declare Example = 2;
	#debug concat ("Code example for keyword: ", this_keyword, "#", str (Example, 0, 0), " \n")
	#switch (Example)
	#case (1)
	// write a 32-bit value
	#declare AnInteger = 4091728320; // 0xf3e2d1c0
	#declare R = AnInteger;
	#declare Byte_0 = mod (R, 256);
	#declare R = div (R, 256);
	#declare Byte_1 = mod (R, 256);
	#declare R = div (R, 256);
	#declare Byte_2 = mod (R, 256);
	#declare R = div (R, 256);
	#declare Byte_3 = mod (R, 256);
	
	#fopen SomeFile "LittleEndian.bin" write
	#write (SomeFile, uint8 Byte_0)
	#write (SomeFile, uint8 Byte_1)
	#write (SomeFile, uint8 Byte_2)
	#write (SomeFile, uint8 Byte_3)
	#fclose SomeFile
	
	#fopen SomeFile "BigEndian.bin" write
	#write (SomeFile, uint8 Byte_3)
	#write (SomeFile, uint8 Byte_2)
	#write (SomeFile, uint8 Byte_1)
	#write (SomeFile, uint8 Byte_0)
	#fclose SomeFile
	
	#error "Finished"
	#error NO // Stop render
	#break
	
	#case (2)
	#declare UnsignedInteger = 4091728320; // 0xf3e2d1c0
	
	#debug "\n\n"
	#debug str(UnsignedInteger, 0, 0)
	#debug "\n"
	
	#declare NoOfBits = ceil (ln (UnsignedInteger) / ln (2));
	
	#declare TheBits = array [NoOfBits];
	
	#declare R = UnsignedInteger;
	#for (I, 0, NoOfBits-1)
	    #declare TheBits [I] = mod (R, 2);
	    #declare R = div (R, 2);
	#end // for
	
	#declare N = 0;
	#for (I, NoOfBits-1, 0, -1)
	    #declare InvertedBit = 1 - TheBits [I];
	    #declare N = 2*N + InvertedBit;
	#end // for
	
	#debug str(N, 0, 0) // 203238975 = 0x0C1D2E3F
	#debug "\n\n"
	
	#error "Finished"
	
	
	//If you get to a point where you need to mask away all other bits than the lower
	//32 your can do this:
	
	#declare N = mod(N, pow(2, 32));
	#break
	#case (3)
	// Thorsten
	#declare uint32 = function(x) { select(x-2147483648, x, x-4294967296) }
	#break
	#case (4)
	// TOK 
	// #declare UnsignedInteger = 0; // 0x00000000
	// #declare UnsignedInteger = 1; // 0x00000001
	// #declare UnsignedInteger = pow(2, 31) - 1; // 0x7FFFFFFF
	// #declare UnsignedInteger = pow(2, 31); // 0x80000000
	// #declare UnsignedInteger = pow(2, 31) + 1; // 0x80000001
	// #declare UnsignedInteger = pow(2, 32) - 1; // 0xFFFFFFFF
	
	#declare UnsignedInteger = 4321; // 0x000010E1
	// #declare UnsignedInteger = 1059986700; // 0x3F2E1D0C
	// #declare UnsignedInteger = 4091728320; // 0xF3E2D1C0
	
	#if (UnsignedInteger < pow(2, 31))
	    #declare N = UnsignedInteger;
	#else
	    #declare N = UnsignedInteger - pow(2, 32);
	#end // if
	
	#debug concat("\n\n", str(N, 0, 0), "\n\n")
	
	#fopen SomeFile "LitteEndian32.bin" write
	#write (SomeFile, sint32le N)
	#fclose SomeFile
	
	#fopen SomeFile "BigEndian32.bin" write
	#write (SomeFile, sint32be N)
	#fclose SomeFile
	
	#error "Finished"
	#break
	#end
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "uint16be";
#if (Keyword = this_keyword)  
	// Code example for keyword: uint16be
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: uint16be
	/*
	uint16be, uint16le - unsigned 16-bit word (0..65535)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "uint16le";
#if (Keyword = this_keyword)  
	// Code example for keyword: uint16le
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: uint16le
	/*
	uint16be, uint16le - unsigned 16-bit word (0..65535)
	Additionally it is now possible to write 8, 16, and 32-bit words to an external file.
	These words may be arranged in either little or big-endian fashion. Placing one of the 
	following keywords in the argument list of a #write statement causes the values up to 
	the next comma to be written in binary format, using 2's complement integer representation, 
	rounded to the nearest integer in the representable range:
	Keywords ending in "be" will cause the values to be written most significant byte first 
	(big endian, aka network byte order) while those ending in "le" will instead write the least 
	significant byte first (little endian, Intel format).
	*/
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "u_steps";
#if (Keyword = this_keyword)  
	// Code example for keyword: u_steps
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: u_steps
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "ultra_wide_angle";
#if (Keyword = this_keyword)  
	// Code example for keyword: ultra_wide_angle
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: ultra_wide_angle
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "undef";
#if (Keyword = this_keyword)  
	// Code example for keyword: undef
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: undef
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "union";
#if (Keyword = this_keyword) 
	// KEYWORD DISAMBIGUATION BLOCK
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "union csg \n"
	#warning " - or - \n"
	#warning "union torus \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "union csg";
#if (Keyword = this_keyword)  
	// Code example for keyword: union csg
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: union csg
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "union torus";
#if (Keyword = this_keyword)  
	// Code example for keyword: union torus
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: union torus
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "up";
#if (Keyword = this_keyword)  
	// Code example for keyword: up
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: up
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "use_alpha";
#if (Keyword = this_keyword) 
	// KEYWORD DISAMBIGUATION BLOCK
	// Version 0.1
	// Author: Bill "Bald Eagle" Walker
	// March 2021
	// Checked [ ]	Checked by:
	#warning Ambiguous
	#warning "Please specify: \n"
	#warning "use_alpha image pattern \n"
	#warning " - or - \n"
	#warning "use_alpha finish \n"
	#error NO
#end

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "use_alpha image pattern";
#if (Keyword = this_keyword) 
	// Code example for keyword: use_alpha image pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: use_alpha image pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "use_alpha finish ";
#if (Keyword = this_keyword)  
	// Code example for keyword: use_alpha finish 
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: use_alpha finish 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "use_color";
#if (Keyword = this_keyword)  
	// Code example for keyword: use_color
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: use_color
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "use_colour";
#if (Keyword = this_keyword)  
	// Code example for keyword: use_colour
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: use_colour
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "use_index";
#if (Keyword = this_keyword)  
	// Code example for keyword: use_index
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: use_index
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "user_defined projection";
#if (Keyword = this_keyword)  
	// Code example for keyword: user_defined projection
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: user_defined projection
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "user_defined pattern";
#if (Keyword = this_keyword)  
	// Code example for keyword: user_defined pattern
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: user_defined pattern
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "utf8";
#if (Keyword = this_keyword)  
	// Code example for keyword: utf8
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: utf8
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "uv_indices";
#if (Keyword = this_keyword)  
	// Code example for keyword: uv_indices
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: uv_indices
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "uv_mapping";
#if (Keyword = this_keyword)  
	// Code example for keyword: uv_mapping
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: uv_mapping
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "uv_vectors";
#if (Keyword = this_keyword)  
	// Code example for keyword: uv_vectors
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: uv_vectors 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// ################################################# V #################################################

#declare this_keyword = "v";
#if (Keyword = this_keyword)  
	// Code example for keyword: v
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: v 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "v_steps";
#if (Keyword = this_keyword)  
	// Code example for keyword: v_steps
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: v_steps
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "val";
#if (Keyword = this_keyword)  
	// Code example for keyword: val
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: val
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "variance";
#if (Keyword = this_keyword)  
	// Code example for keyword: variance
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: variance
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vaxis_rotate";
#if (Keyword = this_keyword)  
	// Code example for keyword: vaxis_rotate
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vaxis_rotate
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vcross";
#if (Keyword = this_keyword)  
	// Code example for keyword: vcross
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vcross
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vdot";
#if (Keyword = this_keyword)  
	// Code example for keyword: vdot
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vdot
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "version";
#if (Keyword = this_keyword)  
	// Code example for keyword: version
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: version
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vertex_vectors";
#if (Keyword = this_keyword)  
	// Code example for keyword: vertex_vectors
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vertex_vectors
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vlength";
#if (Keyword = this_keyword)  
	// Code example for keyword: vlength
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vlength
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vnormalize";
#if (Keyword = this_keyword)  
	// Code example for keyword: vnormalize
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vnormalize
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vrotate";
#if (Keyword = this_keyword)  
	// Code example for keyword: vrotate
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vrotate
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vstr";
#if (Keyword = this_keyword)  
	// Code example for keyword: vstr
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vstr
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "vturbulence";
#if (Keyword = this_keyword)  
	// Code example for keyword: vturbulence
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: vturbulence
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# W #################################################

#declare this_keyword = "warning";
#if (Keyword = this_keyword)  
	// Code example for keyword: warning
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: warning
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "warp";
#if (Keyword = this_keyword)  
	// Code example for keyword: warp
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: warp
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "water_level";
#if (Keyword = this_keyword)  
	// Code example for keyword: water_level
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: water_level
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "waves";
#if (Keyword = this_keyword) 
	// Code example for keyword: waves
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	 
	// Code example for keyword: waves
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render

#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "while";
#if (Keyword = this_keyword)  
	// Code example for keyword: while
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: while
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "width";
#if (Keyword = this_keyword)  
	// Code example for keyword: width
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: width
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "wood";
#if (Keyword = this_keyword)  
	// Code example for keyword: wood
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: wood
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "wrinkles";
#if (Keyword = this_keyword)  
	// Code example for keyword: wrinkles
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: wrinkles
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render 
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "write";
#if (Keyword = this_keyword)  
	// Code example for keyword: write
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: write
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# X #################################################

#declare this_keyword = "x";
#if (Keyword = this_keyword)  
	// Code example for keyword: x
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: x
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# Y #################################################

#declare this_keyword = "y";
#if (Keyword = this_keyword)  
	// Code example for keyword: y
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: y 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// -----------------------------------------------------------------------------------------------------

#declare this_keyword = "yes";
#if (Keyword = this_keyword)  
	// Code example for keyword: yes
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: yes 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end  

// ################################################# Z #################################################

#declare this_keyword = "z";
#if (Keyword = this_keyword)  
	// Code example for keyword: z
	// Version 0.1
	// Author: 
	// March 2021
	// Checked [ ]	Checked by:
	// Code example for keyword: z 
	#debug concat ("Code example for keyword: ", this_keyword, " \n")
	#error NE // Stop render
	
#end 

